@@ -1,13 +1,17 @@
 package Crixa;
-# git description: v0.09-5-g0dc55d3
 
-# ABSTRACT: A Cleaner API for Net::AMQP::RabbitMQ
-$Crixa::VERSION = '0.10';
-use Moose;
+use v5.10;
+
+use strict;
+use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.11';
+
+use Moose;
+
 use Crixa::Channel;
-use Net::AMQP::RabbitMQ;
+use Net::AMQP::RabbitMQ 0.009000;
 
 with qw(Crixa::HasMQ);
 
@@ -19,10 +23,21 @@ has '+_mq' => (
     handles  => [qw( disconnect )],
 );
 
-has host => ( isa => 'Str', is => 'ro', required => 1, );
+has host => (
+    isa      => 'Str',
+    is       => 'ro',
+    required => 1,
+);
 
-has [qw(user password)] => ( isa => 'Str', is => 'ro' );
-has [qw(port)] => ( isa => 'Int', is => 'ro' );
+has [qw(user password)] => (
+    isa => 'Str',
+    is  => 'ro',
+);
+
+has port => (
+    isa => 'Int',
+    is  => 'ro',
+);
 
 has _channel_id => (
     isa     => 'Int',
@@ -32,16 +47,18 @@ has _channel_id => (
         _next_channel_id   => 'inc',
         release_channel_id => 'dec',
         reset_channel_id   => 'reset',
-    }
+    },
 );
 
 sub _build_mq { Net::AMQP::RabbitMQ->new; }
 
+## no critic (Subroutines::ProhibitBuiltinHomonyms)
 sub connect {
     my $self = shift->new(@_);
     $self->_connect_mq($self);
     return $self;
 }
+## use critic
 
 sub _connect_mq {
     my ( $self, $crixa ) = @_;
@@ -81,6 +98,8 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+# ABSTRACT: A Cleaner API for Net::AMQP::RabbitMQ
+
 __END__
 
 =pod
@@ -91,7 +110,7 @@ Crixa - A Cleaner API for Net::AMQP::RabbitMQ
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -101,15 +120,11 @@ version 0.10
     my $channel  = $mq->channel;
     my $exchange = $channel->exchange( name => 'hello' );
 
-    sub send {
-        $exchange->publish('Hello World');
-    }
+    $exchange->publish('Hello World');
 
     my $queue = $exchange->queue( name => 'hello' );
 
-    sub receive {
-        $queue->handle_message( sub { say $_->body } );
-    }
+    $queue->handle_message( sub { say $_->body } );
 
 =head1 DESCRIPTION
 
@@ -121,6 +136,8 @@ version 0.10
 This module provides a more natural API over L<Net::AMQP::RabbitMQ>, with
 separate objects for channels, exchanges, and queues.
 
+=encoding UTF-8
+
 =head1 WARNING
 
 B<Crixa is still in development and the API may change in the future!>
@@ -307,7 +324,7 @@ Torsten Raudssus <torsten@raudss.us>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 - 2014 by Chris Prather.
+This software is copyright (c) 2012 - 2015 by Chris Prather.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
