@@ -1,13 +1,20 @@
 package Crixa::Exchange;
-# ABSTRACT: A Crixa Exchange
-$Crixa::Exchange::VERSION = '0.10';
-use 5.10.0;
-use Moose;
+
+use strict;
+use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.11';
+
+use Moose;
+
 with qw(Crixa::HasMQ);
 
-has name => ( isa => 'Str', is => 'ro', required => 1 );
+has name => (
+    isa      => 'Str',
+    is       => 'ro',
+    required => 1,
+);
 
 has channel => (
     isa      => 'Crixa::Channel',
@@ -66,7 +73,7 @@ sub publish {
     my $self = shift;
     my $args = @_ > 1 ? {@_} : ref $_[0] ? $_[0] : { body => $_[0] };
 
-    my $routing_key = delete $args->{routing_key} // '';
+    my $routing_key = delete $args->{routing_key} // q{};
     my $body = delete $args->{body}
         || confess(
         'You must supply a body when calling the publish() method');
@@ -83,12 +90,14 @@ sub publish {
     );
 }
 
+## no critic (Subroutines::ProhibitBuiltinHomonyms)
 sub delete {
     my $self = shift;
     my $args = @_ > 1 ? {@_} : ref $_[0] ? $_[0] : {};
 
     $self->_mq->exchange_delete( $self->channel->id, $self->name, $args );
 }
+## use critic
 
 sub _props {
     my $self = shift;
@@ -101,6 +110,8 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+# ABSTRACT: A Crixa Exchange
+
 __END__
 
 =pod
@@ -111,13 +122,15 @@ Crixa::Exchange - A Crixa Exchange
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
 This class represents a single exchange. With RabbitMQ, messages are published
 to an exchange. Queues can then connect to exchanges and receive those messages.
 
+=encoding UTF-8
+
 =head1 METHODS
 
 This class provides the following methods:
@@ -371,7 +384,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 - 2014 by Chris Prather.
+This software is copyright (c) 2012 - 2015 by Chris Prather.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
