@@ -1,12 +1,16 @@
 package Crixa::HasMQ;
-# ABSTRACT: For internal use only
-$Crixa::HasMQ::VERSION = '0.10';
-use Moose::Role;
+
+use strict;
+use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.11';
+
+use Moose::Role;
+
 use Moose::Util::TypeConstraints qw( duck_type );
 
-# XXX - Test::Net::RabbitMQ doesn't support some of the method we call
+# XXX - Test::Net::RabbitMQ doesn't support some of the methods we call
 # internally so we won't require them but it sure would be nice to patch
 # Test::Net::RabbitMQ to include these:
 #
@@ -35,6 +39,8 @@ has _mq => (
 
 1;
 
+# ABSTRACT: For internal use only
+
 __END__
 
 =pod
@@ -45,12 +51,14 @@ Crixa::HasMQ - For internal use only
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
 This is used internally by Crixa. There are no user accessible parts here.
 
+=encoding UTF-8
+
 =head1 AUTHORS
 
 =over 4
@@ -67,7 +75,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 - 2014 by Chris Prather.
+This software is copyright (c) 2012 - 2015 by Chris Prather.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
