@@ -1,10 +1,13 @@
 package Crixa::Message;
-# ABSTRACT: A Crixa Message
-$Crixa::Message::VERSION = '0.10';
-use 5.10.0;
-use Moose;
+
+use strict;
+use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.11';
+
+use Moose;
+
 has channel => (
     isa      => 'Crixa::Channel',
     is       => 'ro',
@@ -72,11 +75,26 @@ has delivery_tag => (
 );
 
 has message_count => (
-    is       => 'ro',
-    isa      => 'Int',
-    required => 1,
+    is        => 'ro',
+    isa       => 'Int',
+    predicate => '_has_message_count',
 );
 
+has consumer_tag => (
+    is        => 'ro',
+    isa       => 'Str',
+    predicate => '_has_consumer_tag',
+);
+
+sub BUILD {
+    my $self = shift;
+
+    die 'A Crixa::Message must have a message_count or consumer_tag'
+        unless $self->_has_message_count() || $self->_has_consumer_tag();
+
+    return;
+}
+
 sub ack {
     my $self = shift;
     $self->channel->ack( $self->delivery_tag );
@@ -86,6 +104,8 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+# ABSTRACT: A Crixa Message
+
 __END__
 
 =pod
@@ -96,7 +116,7 @@ Crixa::Message - A Crixa Message
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
@@ -104,6 +124,8 @@ This class represents a single queue. With RabbitMQ, messages are published to
 exchanges, which then routes the message to one or more queues. You then
 consume those messages from the queue.
 
+=encoding UTF-8
+
 =head1 METHODS
 
 This class provides the following methods:
@@ -173,6 +195,9 @@ consumer to receive it has had a chance to acknowledge it.
 The number of messages left in the queue at the time this message was
 delivered.
 
+Note that this is only set for messages which are not received via the C<<
+Crixa::Queue->consume() >> method.
+
 =head2 $message->routing_key
 
 The routing path on which the message was received.
@@ -181,9 +206,17 @@ The routing path on which the message was received.
 
 The exchange to which this message was published
 
+=head2 $message->delivery_tag
+
+The delivery tag for a given message. This is used when the C<<
+$message->ack() >> method is called.
+
 =head2 $message->consumer_tag
 
-The tag for the message's consumer.
+The tag for the consumer associated with the message, if one exists.
+
+Note that this is only set for messages which are received via the C<<
+Crixa::Queue->consume() >> method.
 
 =head2 Crixa::Message->new(...)
 
@@ -206,7 +239,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 - 2014 by Chris Prather.
+This software is copyright (c) 2012 - 2015 by Chris Prather.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
