@@ -1,10 +1,13 @@
 package Crixa::Queue;
-# ABSTRACT: A Crixa Queue
-$Crixa::Queue::VERSION = '0.10';
-use 5.10.0;
-use Moose;
+
+use strict;
+use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.11';
+
+use Moose;
+
 use Crixa::Message;
 
 with qw(Crixa::HasMQ);
@@ -43,7 +46,7 @@ has exclusive => (
 has auto_delete => (
     is      => 'ro',
     isa     => 'Bool',
-    default => 1,
+    default => 0,
 );
 
 sub BUILD {
@@ -63,7 +66,7 @@ sub _queue_declare {
 
     return $self->_mq->queue_declare(
         $self->channel->id,
-        $self->name // '',
+        $self->name // q{},
         $props,
     );
 }
@@ -86,7 +89,7 @@ sub check_for_message {
 
 sub _inflate_message {
     my $self = shift;
-    my $msg = shift;
+    my $msg  = shift;
 
     return unless defined $msg;
 
@@ -111,6 +114,7 @@ sub handle_message {
     confess 'Something unusual happened.';
 }
 
+## no critic (Subroutines::ProhibitBuiltinHomonyms)
 sub bind {
     my $self = shift;
     my $args = @_ > 1 ? {@_} : ref $_[0] ? $_[0] : {};
@@ -128,7 +132,23 @@ sub delete {
     my $self = shift;
     my $args = @_ > 1 ? {@_} : ref $_[0] ? $_[0] : {};
 
-    $self->_mq->queue_delete( $self->channel->id, $self->name, $args )
+    $self->_mq->queue_delete( $self->channel->id, $self->name, $args );
+}
+## use critic
+
+sub consume {
+    my $self = shift;
+    my $cb   = shift;
+    my $args = @_ > 1 ? {@_} : ref $_[0] ? $_[0] : {};
+
+    my $timeout = delete $args->{timeout};
+
+    my $tag = $self->_mq->consume( $self->channel->id, $self->name, $args );
+    while (1) {
+        my $raw = $self->_mq->recv( $timeout ? $timeout : () );
+        last unless $cb->( $self->_inflate_message($raw) );
+    }
+    $self->_mq->cancel( $self->channel->id, $tag );
 }
 
 sub _props {
@@ -142,6 +162,8 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+# ABSTRACT: A Crixa Queue
+
 __END__
 
 =pod
@@ -152,7 +174,7 @@ Crixa::Queue - A Crixa Queue
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
@@ -160,6 +182,8 @@ This class represents a single queue. With RabbitMQ, messages are published to
 exchanges, which then routes the message to one or more queues. You then
 consume those messages from the queue.
 
+=encoding UTF-8
+
 =head1 METHODS
 
 This class provides the following methods:
@@ -230,6 +254,72 @@ This defaults to true.
 
 =back
 
+=head2 $queue->consume($callback, ...)
+
+This method start consuming message via the AMQP consume API using the given
+callback. Internally, this uses the C<poll()> system call to efficiently wait
+for messages to come in. You are strongly encouraged to use this over the
+C<wait_for_message()> methods and instead of calling C<check_for_message()> in
+a loop.
+
+The callback you provide will be passed a single optional argument. This
+argument is always a C<Crixa::Message> object. However, if you specified a
+timeout (see below), then your callback may be called without any arguments at
+all.
+
+The callback is expected to return true or false. If it returns true, Crixa
+will continue waiting for new messages. If it returns false, it will cancel
+the consumer and the C<consume()> method will return.
+
+Note that if you create an "auto-delete" queue, then it will be deleted after
+the last consumer it cancelled.
+
+This method also accepts either a hash or hashref with the following keys
+after the callback:
+
+=over 4
+
+=item * timeout => $integer
+
+This is an optional timeout for each internal call to the C<<
+Net::AMQP::RabbitMQ->recv() >> method. If you specify this, then your callback
+will be called without any arguments.
+
+=item * consumer_tag => $string
+
+A string identifying the consumer. If you don't provide one it will be
+generated automatically. This will be available from the L<Crixa::Message>
+object passed to your callback, regardless of whether it is auto-generated or
+not.
+
+=item * no_local => $bool
+
+If this is true, then the server will not send messages to the same connection
+as the one from which they were published.
+
+This defaults to false.
+
+=item * no_ack => $bool
+
+If this is true, then the message is not acknowledged as it is taken from the
+queue. You will need to explicitly acknowledge it using the C<ack> method on
+the L<Crixa::Channel> object from which the message came.
+
+If this is false, then the message is acknowledged immediately. Calling the
+C<ack> method later with this message's delivery tag will be an error.
+
+This defaults to true.
+
+=item * exclusive => $bool
+
+If this is true, then only this consumer may access the queue. If another
+consumer attempts to access the queue at the same time it will received an
+error.
+
+This defaults to false.
+
+=back
+
 =head2 $queue->wait_for_message(...)
 
 This blocks until a message is ready. It always returns a single message.
@@ -346,7 +436,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 - 2014 by Chris Prather.
+This software is copyright (c) 2012 - 2015 by Chris Prather.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
